@@ -4,6 +4,7 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
+	"math/bits"
 	"math/rand"
 	"os"
 	"os/exec"
@@ -15,7 +16,6 @@ import (
 
 	"github.com/itchyny/bed/event"
 	"github.com/itchyny/bed/layout"
-	"github.com/itchyny/bed/mathutil"
 	"github.com/itchyny/bed/state"
 )
 
@@ -508,7 +508,7 @@ func (m *Manager) State() (map[int]*state.WindowState, layout.Layout, int, error
 		if l, ok := layouts[i]; ok {
 			var err error
 			if states[i], err = window.state(
-				hexWindowWidth(l.Width()), mathutil.MaxInt(l.Height()-2, 1),
+				hexWindowWidth(l.Width()), max(l.Height()-2, 1),
 			); err != nil {
 				return nil, m.layout, 0, err
 			}
@@ -518,18 +518,8 @@ func (m *Manager) State() (map[int]*state.WindowState, layout.Layout, int, error
 }
 
 func hexWindowWidth(width int) int {
-	if width > 146 {
-		return 32
-	} else if width > 114 {
-		return 24
-	} else if width > 82 {
-		return 16
-	} else if width > 64 {
-		return 12
-	} else if width > 50 {
-		return 8
-	}
-	return 4
+	width = min(max((width-18)/4, 4), 256)
+	return width & (0b11 << (bits.Len(uint(width)) - 2))
 }
 
 func (m *Manager) writeFile(r *event.Range, name string) (string, int64, error) {
