@@ -1345,7 +1345,7 @@ func TestWindowEventUndoRedo(t *testing.T) {
 	}()
 
 	waitRedraw := func(count int) {
-		for i := 0; i < count; i++ {
+		for range count {
 			<-redrawCh
 		}
 	}
